﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using Windows.ApplicationModel.Resources.Core;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;
using System.Collections.Specialized;

// The data model defined by this file serves as a representative example of a strongly-typed
// model that supports notification when members are added, removed, or modified.  The property
// names chosen coincide with data bindings in the standard item templates.
//
// Applications may use this model as a starting point and build on it, or discard it entirely and
// replace it with something appropriate to their needs.

namespace Food.Data
{
    /// <summary>
    /// Base class for <see cref="SampleDataItem3"/> and <see cref="SampleDataGroup3"/> that
    /// defines properties common to both.
    /// </summary>
    [Windows.Foundation.Metadata.WebHostHidden]
    public abstract class SampleDataCommon3 : Food.Common.BindableBase
    {
        private static Uri _baseUri = new Uri("ms-appx:///");

        public SampleDataCommon3(String uniqueId, String title, String subtitle, String imagePath, String description)
        {
            this._uniqueId = uniqueId;
            this._title = title;
            this._subtitle = subtitle;
            this._description = description;
            this._imagePath = imagePath;
        }

        private string _uniqueId = string.Empty;
        public string UniqueId
        {
            get { return this._uniqueId; }
            set { this.SetProperty(ref this._uniqueId, value); }
        }

        private string _title = string.Empty;
        public string Title
        {
            get { return this._title; }
            set { this.SetProperty(ref this._title, value); }
        }

        private string _subtitle = string.Empty;
        public string Subtitle
        {
            get { return this._subtitle; }
            set { this.SetProperty(ref this._subtitle, value); }
        }

        private string _description = string.Empty;
        public string Description
        {
            get { return this._description; }
            set { this.SetProperty(ref this._description, value); }
        }

        private ImageSource _image = null;
        private String _imagePath = null;
        public ImageSource Image
        {
            get
            {
                if (this._image == null && this._imagePath != null)
                {
                    this._image = new BitmapImage(new Uri(SampleDataCommon3._baseUri, this._imagePath));
                }
                return this._image;
            }

            set
            {
                this._imagePath = null;
                this.SetProperty(ref this._image, value);
            }
        }

        public void SetImage(String path)
        {
            this._image = null;
            this._imagePath = path;
            this.OnPropertyChanged("Image");
        }

        public override string ToString()
        {
            return this.Title;
        }
    }

    /// <summary>
    /// Generic item data model.
    /// </summary>
    public class SampleDataItem3 : SampleDataCommon3
    {
        public SampleDataItem3(String uniqueId, String title, String subtitle, String imagePath, String description, String content, int ColSpan, int RowSpan, SampleDataGroup3 group)
            : base(uniqueId, title, subtitle, imagePath, description)
        {
            this._content = content;
            this._ColSpan = ColSpan;
            this._RowSpan = RowSpan;
            this._group = group;
        }

        private string _content = string.Empty;
        public string Content
        {
            get { return this._content; }
            set { this.SetProperty(ref this._content, value); }
        }

        private int _ColSpan = 1;
        public int ColSpan
        {
            get { return this._ColSpan; }
            set { this.SetProperty(ref this._ColSpan, value); }
        }

        private int _RowSpan = 1;
        public int RowSpan
        {
            get { return this._RowSpan; }
            set { this.SetProperty(ref this._RowSpan, value); }
        }

        private SampleDataGroup3 _group;
        public SampleDataGroup3 Group
        {
            get { return this._group; }
            set { this.SetProperty(ref this._group, value); }
        }
    }

    /// <summary>
    /// Generic group data model.
    /// </summary>
    public class SampleDataGroup3 : SampleDataCommon3
    {
        public SampleDataGroup3(String uniqueId, String title, String subtitle, String imagePath, String description)
            : base(uniqueId, title, subtitle, imagePath, description)
        {
            Items.CollectionChanged += ItemsCollectionChanged;
        }

        private void ItemsCollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            // Provides a subset of the full items collection to bind to from a GroupedItemsPage
            // for two reasons: GridView will not virtualize large items collections, and it
            // improves the user experience when browsing through groups with large numbers of
            // items.
            //
            // A maximum of 12 items are displayed because it results in filled grid columns
            // whether there are 1, 2, 3, 4, or 6 rows displayed

            switch (e.Action)
            {
                case NotifyCollectionChangedAction.Add:
                    if (e.NewStartingIndex < 12)
                    {
                        TopItems.Insert(e.NewStartingIndex, Items[e.NewStartingIndex]);
                        if (TopItems.Count > 12)
                        {
                            TopItems.RemoveAt(12);
                        }
                    }
                    break;
                case NotifyCollectionChangedAction.Move:
                    if (e.OldStartingIndex < 12 && e.NewStartingIndex < 12)
                    {
                        TopItems.Move(e.OldStartingIndex, e.NewStartingIndex);
                    }
                    else if (e.OldStartingIndex < 12)
                    {
                        TopItems.RemoveAt(e.OldStartingIndex);
                        TopItems.Add(Items[11]);
                    }
                    else if (e.NewStartingIndex < 12)
                    {
                        TopItems.Insert(e.NewStartingIndex, Items[e.NewStartingIndex]);
                        TopItems.RemoveAt(12);
                    }
                    break;
                case NotifyCollectionChangedAction.Remove:
                    if (e.OldStartingIndex < 12)
                    {
                        TopItems.RemoveAt(e.OldStartingIndex);
                        if (Items.Count >= 12)
                        {
                            TopItems.Add(Items[11]);
                        }
                    }
                    break;
                case NotifyCollectionChangedAction.Replace:
                    if (e.OldStartingIndex < 12)
                    {
                        TopItems[e.OldStartingIndex] = Items[e.OldStartingIndex];
                    }
                    break;
                case NotifyCollectionChangedAction.Reset:
                    TopItems.Clear();
                    while (TopItems.Count < Items.Count && TopItems.Count < 12)
                    {
                        TopItems.Add(Items[TopItems.Count]);
                    }
                    break;
            }
        }

        private ObservableCollection<SampleDataItem3> _items = new ObservableCollection<SampleDataItem3>();
        public ObservableCollection<SampleDataItem3> Items
        {
            get { return this._items; }
        }

        private ObservableCollection<SampleDataItem3> _topItem = new ObservableCollection<SampleDataItem3>();
        public ObservableCollection<SampleDataItem3> TopItems
        {
            get { return this._topItem; }
        }
    }

    /// <summary>
    /// Creates a collection of groups and items with hard-coded content.
    /// 
    /// SampleDataSource3 initializes with placeholder data rather than live production
    /// data so that sample data is provided at both design-time and run-time.
    /// </summary>
    public sealed class SampleDataSource3
    {
        private static SampleDataSource3 _SampleDataSource3 = new SampleDataSource3();

        private ObservableCollection<SampleDataGroup3> _allGroups = new ObservableCollection<SampleDataGroup3>();
        public ObservableCollection<SampleDataGroup3> AllGroups
        {
            get { return this._allGroups; }
        }

        public static IEnumerable<SampleDataGroup3> GetGroups(string uniqueId)
        {
            if (!uniqueId.Equals("AllGroups")) throw new ArgumentException("Only 'AllGroups' is supported as a collection of groups");

            return _SampleDataSource3.AllGroups;
        }

        public static SampleDataGroup3 GetGroup(string uniqueId)
        {
            // Simple linear search is acceptable for small data sets
            var matches = _SampleDataSource3.AllGroups.Where((group) => group.UniqueId.Equals(uniqueId));
            if (matches.Count() == 1) return matches.First();
            return null;
        }

        public static SampleDataItem3 GetItem(string uniqueId)
        {
            // Simple linear search is acceptable for small data sets
            var matches = _SampleDataSource3.AllGroups.SelectMany(group => group.Items).Where((item) => item.UniqueId.Equals(uniqueId));
            if (matches.Count() == 1) return matches.First();
            return null;
        }

        public SampleDataSource3()
        {
            String ITEM_CONTENT = String.Format("Item Content: {0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}",
                        "Curabitur class aliquam vestibulum nam curae maecenas sed integer cras phasellus suspendisse quisque donec dis praesent accumsan bibendum pellentesque condimentum adipiscing etiam consequat vivamus dictumst aliquam duis convallis scelerisque est parturient ullamcorper aliquet fusce suspendisse nunc hac eleifend amet blandit facilisi condimentum commodo scelerisque faucibus aenean ullamcorper ante mauris dignissim consectetuer nullam lorem vestibulum habitant conubia elementum pellentesque morbi facilisis arcu sollicitudin diam cubilia aptent vestibulum auctor eget dapibus pellentesque inceptos leo egestas interdum nulla consectetuer suspendisse adipiscing pellentesque proin lobortis sollicitudin augue elit mus congue fermentum parturient fringilla euismod feugiat");

            var group1 = new SampleDataGroup3("Group-1",
                    "",
                    "",
                    "Assets/DarkGray.png",
                    "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");
            group1.Items.Add(new SampleDataItem3("Big-Group-1-Item-1",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.  ",
                    "Assets/SpokePage/SpokeImg17.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    53, 104,
                    group1));
            group1.Items.Add(new SampleDataItem3("Medium-Group-1-Item-2",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/SpokePage/SpokeImg11.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group1));
            group1.Items.Add(new SampleDataItem3("Medium-Group-1-Item-3",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/HubPage/HubImage10.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group1));
            group1.Items.Add(new SampleDataItem3("Medium-Group-1-Item-4",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/SpokePage/SpokeImg17.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group1));
            group1.Items.Add(new SampleDataItem3("Medium-Group-1-Item-5",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/SpokePage/SpokeImg10.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group1));
            this.AllGroups.Add(group1);

            var group2 = new SampleDataGroup3("Group-2",
                    "",
                    "Group Subtitle: 2",
                    "Assets/LightGray.png",
                    "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");
            group2.Items.Add(new SampleDataItem3("Big-Group-2-Item-1",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.  ",
                    "Assets/HubPage/HubImage8.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    53, 104,
                    group2));
            group2.Items.Add(new SampleDataItem3("Medium-Group-2-Item-2",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/HubPage/HubImage9.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group2));
            group2.Items.Add(new SampleDataItem3("Medium-Group-2-Item-3",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/HubPage/HubImage10.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group2));
            group2.Items.Add(new SampleDataItem3("Medium-Group-2-Item-4",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/HubPage/HubImage11.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group2));
            group2.Items.Add(new SampleDataItem3("Medium-Group-2-Item-5",
                    "Lorem Ipsum",
                    "It is a long established fact that a reader will be ",
                    "Assets/HubPage/HubImage12.png",
                    "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                    ITEM_CONTENT,
                    33, 52,
                    group2));
            this.AllGroups.Add(group2);

            //var group3 = new SampleDataGroup3("Group-3",
            //        "Ingredients",
            //        "Group Subtitle: 3",
            //        "Assets/MediumGray.png",
            //        "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");
            //group3.Items.Add(new SampleDataItem3("Small-Group-3-Item-1",
            //        "Meat",
            //        "112",
            //        "Assets/MediumGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        27, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Small-Group-3-Item-2",
            //        "Fish",
            //        "98",
            //        "Assets/LightGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        27, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Small-Group-3-Item-3",
            //        "Paneer",
            //        "50",
            //        "Assets/DarkGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        27, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Small-Group-3-Item-4",
            //        "Prawns",
            //        "100",
            //        "Assets/LightGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        27, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Ingregient-Group-3-Item-5",
            //        "Bread",
            //        "125",
            //        "Assets/MediumGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        40, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Ingregient-Group-3-Item-6",
            //        "Gravy",
            //        "150",
            //        "Assets/DarkGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        40, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Ingregient-Group-3-Item-7",
            //        "Rice",
            //        "180",
            //        "Assets/MediumGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        40, 26,
            //        group3));
            //group3.Items.Add(new SampleDataItem3("Ingregient-Group-3-Item-8",
            //       "Potato",
            //       "98",
            //       "Assets/MediumGray.png",
            //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //       ITEM_CONTENT,
            //        40, 26,
            //       group3));
            //this.AllGroups.Add(group3);

            //var group4 = new SampleDataGroup3("Group-4",
            //        "Top Recipes",
            //        "Group Subtitle: 4",
            //        "Assets/LightGray.png",
            //        "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");
            //group4.Items.Add(new SampleDataItem3("Big-Group-4-Item-1",
            //        "Lorem Ipsum",
            //        "It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.  ",
            //        "Assets/HubPage/HubImage8.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        53, 104,
            //        group4));
            //group4.Items.Add(new SampleDataItem3("Medium-Group-4-Item-2",
            //        "Lorem Ipsum",
            //        "It is a long established fact that a reader will be ",
            //        "Assets/HubPage/HubImage9.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        33, 52,
            //        group4));
            //group4.Items.Add(new SampleDataItem3("Medium-Group-4-Item-3",
            //        "Lorem Ipsum",
            //        "It is a long established fact that a reader will be ",
            //        "Assets/HubPage/HubImage10.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        33, 52,
            //        group4));
            //group4.Items.Add(new SampleDataItem3("Medium-Group-4-Item-4",
            //        "Lorem Ipsum",
            //        "It is a long established fact that a reader will be ",
            //        "Assets/HubPage/HubImage11.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        33, 52,
            //        group4));
            //group4.Items.Add(new SampleDataItem3("Medium-Group-4-Item-5",
            //        "Lorem Ipsum",
            //        "It is a long established fact that a reader will be ",
            //        "Assets/HubPage/HubImage12.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        33, 52,
            //        group4));
            ////group4.Items.Add(new SampleDataItem3("Group-4-Item-6",
            ////        "Item Title: 6",
            ////        "Item Subtitle: 6",
            ////        "Assets/LightGray.png",
            ////        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            ////        ITEM_CONTENT,
            ////        group4));
            //this.AllGroups.Add(group4);

            //var group5 = new SampleDataGroup3("Group-5",
            //        "Add-ons",
            //        "Group Subtitle: 5",
            //        "Assets/MediumGray.png",
            //        "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");
            //group5.Items.Add(new SampleDataItem3("Addon-Group-5-Item-1",
            //        "Raita",
            //        "Item Subtitle: 1",
            //        "Assets/HubPage/arrow.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        29, 35,
            //        group5));
            //group5.Items.Add(new SampleDataItem3("Addon-Group-5-Item-2",
            //        "Farsan",
            //        "Item Subtitle: 2",
            //        "Assets/HubPage/arrow.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        29, 35,
            //        group5));
            //group5.Items.Add(new SampleDataItem3("Addon-Group-5-Item-3",
            //        "Chutneys",
            //        "Item Subtitle: 3",
            //        "Assets/HubPage/arrow.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        29, 35,
            //        group5));
            //group5.Items.Add(new SampleDataItem3("Addon-Group-5-Item-4",
            //        "Pickle",
            //        "Item Subtitle: 4",
            //        "Assets/HubPage/arrow.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        29, 35,
            //        group5));
            //group5.Items.Add(new SampleDataItem3("Addon-Group-5-Item-5",
            //        "Salads",
            //        "Item Subtitle: 3",
            //        "Assets/HubPage/arrow.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        29, 35,
            //        group5));
            //group5.Items.Add(new SampleDataItem3("Addon-Group-5-Item-6",
            //        "Juices",
            //        "Item Subtitle: 4",
            //        "Assets/HubPage/arrow.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        29, 35,
            //        group5));
            //this.AllGroups.Add(group5);

            //var group6 = new SampleDataGroup3("Group-6",
            //        "Group Title: 6",
            //        "Group Subtitle: 6",
            //        "Assets/DarkGray.png",
            //        "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-1",
            //        "Item Title: 1",
            //        "Item Subtitle: 1",
            //        "Assets/LightGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-2",
            //        "Item Title: 2",
            //        "Item Subtitle: 2",
            //        "Assets/DarkGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-3",
            //        "Item Title: 3",
            //        "Item Subtitle: 3",
            //        "Assets/MediumGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-4",
            //        "Item Title: 4",
            //        "Item Subtitle: 4",
            //        "Assets/DarkGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-5",
            //        "Item Title: 5",
            //        "Item Subtitle: 5",
            //        "Assets/LightGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-6",
            //        "Item Title: 6",
            //        "Item Subtitle: 6",
            //        "Assets/MediumGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-7",
            //        "Item Title: 7",
            //        "Item Subtitle: 7",
            //        "Assets/DarkGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //group6.Items.Add(new SampleDataItem3("Group-6-Item-8",
            //        "Item Title: 8",
            //        "Item Subtitle: 8",
            //        "Assets/LightGray.png",
            //        "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            //        ITEM_CONTENT,
            //        group6));
            //this.AllGroups.Add(group6);
        }
    }
}
